Excentury
=========

.. image:: http://img.shields.io/pypi/dm/excentury.svg
   :alt: Downloads
   :target: https://pypi.python.org/pypi/excentury#downloads
.. image:: http://img.shields.io/pypi/v/excentury.svg
   :alt: Latest Version
   :target: http://pypi.python.org/pypi/excentury
.. image:: http://img.shields.io/badge/license-BSD-yellow.svg
   :alt: BSD License
   :target: http://opensource.org/licenses/BSD-3-Clause
   
Excentury is a set of libraries written in C++ that enables easy
integration of C++ code into Python and MATLAB projects.

Documentation
-------------

Installation and usage documentation is available in the ``docs/``
directory of the distribution and on `http://excentury.readthedocs.org
<http://excentury.readthedocs.org>`_.
